.. _tutos:

Tutorials
=========

These tutorials are based on `Jupyter notebooks <http://jupyter.org/>`_. Below are the download links to the
original notebooks:

    * :download:`tuto_basics.ipynb <../examples/tuto_basics.ipynb>`

    * :download:`tuto_bandmath.ipynb <../examples/tuto_bandmath.ipynb>`

    * :download:`tuto_burnt_areas_gpt.ipynb <../examples/tuto_burnt_areas_gpt.ipynb>`

    * :download:`tuto_burnt_areas_snappy.ipynb <../examples/tuto_burnt_areas_snappy.ipynb>`

    * :download:`tuto_ship_detection.ipynb <../examples/tuto_ship_detection.ipynb>`

.. toctree::
   :maxdepth: 2

   tutorials/tuto_basics.nblink
   tutorials/tuto_bandmath.nblink
   tutorials/tuto_burnt_areas_gpt.nblink
   tutorials/tuto_burnt_areas_snappy.nblink
   tutorials/tuto_ship_detection.nblink
